All of lore.kernel.org
 help / color / mirror / Atom feed
* [BABELTRACE PATCH] API cleanup name get_timestamp and get_cycles
       [not found] <20120805174635.GA22981@Krystal>
@ 2012-08-07 15:15 ` Julien Desfossez
       [not found] ` <1344352549-32224-1-git-send-email-jdesfossez@efficios.com>
  1 sibling, 0 replies; 2+ messages in thread
From: Julien Desfossez @ 2012-08-07 15:15 UTC (permalink / raw)
  To: mathieu.desnoyers, yannick.brosseau; +Cc: lttng-dev, Julien Desfossez

Rename bt_ctf_get_cycles_timestamp to bt_ctf_get_cycles,
and bt_ctf_get_real_timestamp to bt_ctf_get_timestamp.

Signed-off-by: Julien Desfossez <jdesfossez@efficios.com>
---
 formats/ctf/events.c            |    4 ++--
 include/babeltrace/ctf/events.h |    8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/formats/ctf/events.c b/formats/ctf/events.c
index 06419a1..9693413 100644
--- a/formats/ctf/events.c
+++ b/formats/ctf/events.c
@@ -281,7 +281,7 @@ int bt_ctf_event_get_handle_id(const struct bt_ctf_event *ctf_event)
 	return ret;
 }
 
-uint64_t bt_ctf_get_real_timestamp(const struct bt_ctf_event *ctf_event)
+uint64_t bt_ctf_get_timestamp(const struct bt_ctf_event *ctf_event)
 {
 	struct ctf_event_definition *event = ctf_event->parent;
 	if (event && event->stream->has_timestamp)
@@ -290,7 +290,7 @@ uint64_t bt_ctf_get_real_timestamp(const struct bt_ctf_event *ctf_event)
 		return -1ULL;
 }
 
-uint64_t bt_ctf_get_cycles_timestamp(const struct bt_ctf_event *ctf_event)
+uint64_t bt_ctf_get_cycles(const struct bt_ctf_event *ctf_event)
 {
 	struct ctf_event_definition *event = ctf_event->parent;
 	if (event && event->stream->has_timestamp)
diff --git a/include/babeltrace/ctf/events.h b/include/babeltrace/ctf/events.h
index 419c4c8..4232feb 100644
--- a/include/babeltrace/ctf/events.h
+++ b/include/babeltrace/ctf/events.h
@@ -90,16 +90,16 @@ const struct definition *bt_ctf_get_top_level_scope(const struct bt_ctf_event *e
 const char *bt_ctf_event_name(const struct bt_ctf_event *event);
 
 /*
  * bt_ctf_get_cycles_timestamp: returns the timestamp of the event as written
  * in the packet (in cycles) or -1ULL on error.
  */
-uint64_t bt_ctf_get_cycles_timestamp(const struct bt_ctf_event *event);
+uint64_t bt_ctf_get_cycles(const struct bt_ctf_event *event);
 
 /*
  * bt_ctf_get_real_timestamp: returns the timestamp of the event offsetted
  * with the system clock source (in ns) or -1ULL on error
  */
-uint64_t bt_ctf_get_real_timestamp(const struct bt_ctf_event *event);
+uint64_t bt_ctf_get_timestamp(const struct bt_ctf_event *event);
 
 /*
  * bt_ctf_get_field_list: set list pointer to an array of definition
@@ -90,16 +90,16 @@ const struct definition *bt_ctf_get_top_level_scope(const struct bt_ctf_event *e
 
 /*
- * bt_ctf_get_cycles_timestamp: returns the timestamp of the event as written
+ * bt_ctf_get_cycles: returns the timestamp of the event as written
  * in the packet (in cycles) or -1ULL on error.
  */
@@ -90,16 +90,16 @@ const struct definition *bt_ctf_get_top_level_scope(const struct bt_ctf_event *e
 
 /*
- * bt_ctf_get_real_timestamp: returns the timestamp of the event offsetted
+ * bt_ctf_get_timestamp: returns the timestamp of the event offsetted
  * with the system clock source (in ns) or -1ULL on error
  */
-- 
1.7.10.4

^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [BABELTRACE PATCH] API cleanup name get_timestamp and get_cycles
       [not found] ` <1344352549-32224-1-git-send-email-jdesfossez@efficios.com>
@ 2012-08-07 15:50   ` Mathieu Desnoyers
  0 siblings, 0 replies; 2+ messages in thread
From: Mathieu Desnoyers @ 2012-08-07 15:50 UTC (permalink / raw)
  To: Julien Desfossez; +Cc: lttng-dev

* Julien Desfossez (jdesfossez@efficios.com) wrote:
> Rename bt_ctf_get_cycles_timestamp to bt_ctf_get_cycles,
> and bt_ctf_get_real_timestamp to bt_ctf_get_timestamp.

merged, thanks!

Mathieu

> 
> Signed-off-by: Julien Desfossez <jdesfossez@efficios.com>
> ---
>  formats/ctf/events.c            |    4 ++--
>  include/babeltrace/ctf/events.h |    8 ++++----
>  2 files changed, 6 insertions(+), 6 deletions(-)
> 
> diff --git a/formats/ctf/events.c b/formats/ctf/events.c
> index 06419a1..9693413 100644
> --- a/formats/ctf/events.c
> +++ b/formats/ctf/events.c
> @@ -281,7 +281,7 @@ int bt_ctf_event_get_handle_id(const struct bt_ctf_event *ctf_event)
>  	return ret;
>  }
>  
> -uint64_t bt_ctf_get_real_timestamp(const struct bt_ctf_event *ctf_event)
> +uint64_t bt_ctf_get_timestamp(const struct bt_ctf_event *ctf_event)
>  {
>  	struct ctf_event_definition *event = ctf_event->parent;
>  	if (event && event->stream->has_timestamp)
> @@ -290,7 +290,7 @@ uint64_t bt_ctf_get_real_timestamp(const struct bt_ctf_event *ctf_event)
>  		return -1ULL;
>  }
>  
> -uint64_t bt_ctf_get_cycles_timestamp(const struct bt_ctf_event *ctf_event)
> +uint64_t bt_ctf_get_cycles(const struct bt_ctf_event *ctf_event)
>  {
>  	struct ctf_event_definition *event = ctf_event->parent;
>  	if (event && event->stream->has_timestamp)
> diff --git a/include/babeltrace/ctf/events.h b/include/babeltrace/ctf/events.h
> index 419c4c8..4232feb 100644
> --- a/include/babeltrace/ctf/events.h
> +++ b/include/babeltrace/ctf/events.h
> @@ -90,16 +90,16 @@ const struct definition *bt_ctf_get_top_level_scope(const struct bt_ctf_event *e
>  const char *bt_ctf_event_name(const struct bt_ctf_event *event);
>  
>  /*
> - * bt_ctf_get_cycles_timestamp: returns the timestamp of the event as written
> + * bt_ctf_get_cycles: returns the timestamp of the event as written
>   * in the packet (in cycles) or -1ULL on error.
>   */
> -uint64_t bt_ctf_get_cycles_timestamp(const struct bt_ctf_event *event);
> +uint64_t bt_ctf_get_cycles(const struct bt_ctf_event *event);
>  
>  /*
> - * bt_ctf_get_real_timestamp: returns the timestamp of the event offsetted
> + * bt_ctf_get_timestamp: returns the timestamp of the event offsetted
>   * with the system clock source (in ns) or -1ULL on error
>   */
> -uint64_t bt_ctf_get_real_timestamp(const struct bt_ctf_event *event);
> +uint64_t bt_ctf_get_timestamp(const struct bt_ctf_event *event);
>  
>  /*
>   * bt_ctf_get_field_list: set list pointer to an array of definition
> -- 
> 1.7.10.4
> 

-- 
Mathieu Desnoyers
Operating System Efficiency R&D Consultant
EfficiOS Inc.
http://www.efficios.com

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2012-08-07 15:50 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
     [not found] <20120805174635.GA22981@Krystal>
2012-08-07 15:15 ` [BABELTRACE PATCH] API cleanup name get_timestamp and get_cycles Julien Desfossez
     [not found] ` <1344352549-32224-1-git-send-email-jdesfossez@efficios.com>
2012-08-07 15:50   ` Mathieu Desnoyers

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.